﻿param([string]$OctopusKey="")

$ErrorActionPreference = 'Stop'

# All PowerShell scripts invoked by Calamari will be bootstrapped using this script. This script:
#  1. Declares/overrides various functions for scripts to use
#  2. Loads the $OctopusParameters variables
#  3. Sets a few defaults, like aborting scripts when an error is encountered
#  4. Invokes (using dot-sourcing) the target PowerShell script

# -----------------------------------------------------------------
# Functions
# -----------------------------------------------------------------

function Log-VersionTable
{
	Write-Verbose ($PSVersionTable | Out-String)
}

function Log-EnvironmentInformation
{
	if ($OctopusParameters.ContainsKey("Octopus.Action.Script.SuppressEnvironmentLogging")) {
		if ($OctopusParameters["Octopus.Action.Script.SuppressEnvironmentLogging"] -eq "True") {
			return;
		}
	}

	Write-Host "##octopus[stdout-verbose]"
	Write-Host "PowerShell Environment Information:"
	SafelyLog-EnvironmentVars
	SafelyLog-PathVars
	SafelyLog-ProcessVars
	SafelyLog-ComputerInfoVars
	Write-Host "##octopus[stdout-default]"
}

function SafelyLog-EnvironmentVars
{
	Try
	{
		$operatingSystem = [System.Environment]::OSVersion.ToString()
		Write-Host "  OperatingSystem: $($operatingSystem)"
		
		$osBitVersion = If ([System.Environment]::Is64BitOperatingSystem) {"x64"} Else {"x86"}
		Write-Host "  OsBitVersion: $($osBitVersion)"

		$is64BitProcess = [System.Environment]::Is64BitProcess.ToString()
		Write-Host "  Is64BitProcess: $($is64BitProcess)"

		$currentUser = [System.Security.Principal.WindowsIdentity]::GetCurrent().Name
		Write-Host "  CurrentUser: $($currentUser)"

		$machineName = [System.Environment]::MachineName
		Write-Host "  MachineName: $($machineName)"

		$processorCount = [System.Environment]::ProcessorCount.ToString()
		Write-Host "  ProcessorCount: $($processorCount)"
	}
	Catch
	{
		# silently fail.
	}
}

function SafelyLog-PathVars
{
	Try
	{
		$currentDirectory = [System.IO.Directory]::GetCurrentDirectory()
		Write-Host "  CurrentDirectory: $($currentDirectory)"

		$currentLocation = Get-Location
		Write-Host "  CurrentLocation: $($currentLocation)"
		
		$tempPath = [System.IO.Path]::GetTempPath()
		Write-Host "  TempDirectory: $($tempPath)"
	}
	Catch
	{
		# silently fail.
	}
}

function SafelyLog-ProcessVars
{
	Try
	{
		$hostProcess = [System.Diagnostics.Process]::GetCurrentProcess().ProcessName
		Write-Host "  HostProcessName: $($hostProcess)"
	}
	Catch
	{
		# silently fail.
	}
}

function SafelyLog-ComputerInfoVars
{
	Try
	{
		$OperatingSystem = (Get-WmiObject Win32_OperatingSystem)

		$totalVisibleMemorySize = $OperatingSystem.TotalVisibleMemorySize
		Write-Host "  TotalPhysicalMemory: $($totalVisibleMemorySize) KB"

		$freePhysicalMemory = $OperatingSystem.FreePhysicalMemory
		Write-Host "  AvailablePhysicalMemory: $($freePhysicalMemory) KB"
	}
	Catch
	{
		# silently fail.
	}
}

function Import-ScriptModule([string]$moduleName, [string]$moduleFilePath)
{
	Try 
	{
		Write-Verbose "Importing Script Module '$moduleName' from '$moduleFilePath'"
		Import-Module $moduleFilePath
	}
	Catch
	{
		Write-Warning "Failed to import Script Module '$moduleName'"
		Throw
	}
	Finally
	{
		# Once we've loaded (or failed to load) the script module, 
		# delete the script module file from the filesystem
		# https://github.com/OctopusDeploy/Issues/issues/3895
		Remove-Item $moduleFilePath -Force -ErrorAction SilentlyContinue
	}
}

function Convert-ServiceMessageValue([string]$value)
{
	$valueBytes = [System.Text.Encoding]::UTF8.GetBytes($value)
	return [Convert]::ToBase64String($valueBytes)
}

function Set-OctopusVariable([string]$name, [string]$value) 
{
	$name = Convert-ServiceMessageValue($name)
	$value = Convert-ServiceMessageValue($value)

	Write-Host "##octopus[setVariable name='$($name)' value='$($value)']"
}

function Fail-Step([string] $message)
{
	if($message)
	{
		$message = Convert-ServiceMessageValue($message)
		Write-Host "##octopus[resultMessage message='$($message)']"
	}
	exit -1
}

function New-OctopusArtifact([string]$path, [string]$name="""") 
{
	if ((Test-Path $path) -eq $false) {
		Write-Verbose "There is no file at '$path' right now. Writing the service message just in case the file is available when the artifacts are collected at a later point in time."
	}

	if ($name -eq """")	{
		$name = [System.IO.Path]::GetFileName($path)
	}
	$servicename = Convert-ServiceMessageValue($name)

	$length = ([System.IO.FileInfo]$path).Length;
	if (!$length) {
		$length = 0;
	}
	$length = Convert-ServiceMessageValue($length.ToString());

	$path = $ExecutionContext.SessionState.Path.GetUnresolvedProviderPathFromPSPath($path)
	$path = [System.IO.Path]::GetFullPath($path)
    $servicepath = Convert-ServiceMessageValue($path)

    Write-Verbose "Artifact $name will be collected from $path after this step completes"
	Write-Host "##octopus[createArtifact path='$($servicepath)' name='$($servicename)' length='$($length)']"
}

function Write-Debug([string]$message)
{
	Write-Verbose $message
}

function Write-Verbose([string]$message)
{
	Write-Host "##octopus[stdout-verbose]"
	Write-Host $message
	Write-Host "##octopus[stdout-default]"
}

function Write-Highlight([string]$message)
{
	Write-Host "##octopus[stdout-highlight]"
	Write-Host $message
	Write-Host "##octopus[stdout-default]"
}

function Write-Wait([string]$message)
{
	Write-Host "##octopus[stdout-wait]"
	Write-Host $message
	Write-Host "##octopus[stdout-default]"
}

function Write-Warning()
{
	[CmdletBinding()]
	param([string]$message)

	if ($WarningPreference -eq 'SilentlyContinue') {
		return
	}
	Write-Host "##octopus[stdout-warning]"
	Write-Host $message
	Write-Host "##octopus[stdout-default]"
}

function Decrypt-Variables($iv, $Encrypted) 
{
    function ConvertFromBase64String($str)
    {
        # "nul" is a special string used by Calamari to represent null. "null" is not used as it is a valid Base64 string. 
        if($str -eq "nul")
        {
            return $null;
        }
        else
        {
            [System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String($str))
        }
    }

    $parameters = New-Object 'System.Collections.Generic.Dictionary[String,String]' (,[System.StringComparer]::OrdinalIgnoreCase)

	# Try AesCryptoServiceProvider first (requires .NET 3.5+), otherwise fall back to RijndaelManaged (.NET 2.0)
	# Note using RijndaelManaged will fail in FIPS compliant environments: https://support.microsoft.com/en-us/kb/811833
	$algorithm = $null
	try {
		Add-Type -AssemblyName System.Core
		$algorithm = [System.Security.Cryptography.SymmetricAlgorithm] (New-Object System.Security.Cryptography.AesCryptoServiceProvider)
	} catch {
		Write-Verbose "Could not load AesCryptoServiceProvider, falling back to RijndaelManaged (.NET 2.0)."
		$algorithm = [System.Security.Cryptography.SymmetricAlgorithm] (New-Object System.Security.Cryptography.RijndaelManaged)
	}

	$algorithm.Mode = [System.Security.Cryptography.CipherMode]::CBC
	$algorithm.Padding = [System.Security.Cryptography.PaddingMode]::PKCS7
	$algorithm.KeySize = 128
	$algorithm.BlockSize = 128 # AES is just Rijndael with a fixed block size
	$algorithm.Key = [System.Convert]::FromBase64String($OctopusKey)
	$algorithm.IV =[System.Convert]::FromBase64String($iv)
	$decryptor = [System.Security.Cryptography.ICryptoTransform]$algorithm.CreateDecryptor()

	$memoryStream = new-Object IO.MemoryStream @(,[System.Convert]::FromBase64String($Encrypted)) 
	$cryptoStream = new-Object Security.Cryptography.CryptoStream $memoryStream,$decryptor,"Read" 
	$streamReader = new-Object IO.StreamReader $cryptoStream 
	while($streamReader.EndOfStream -eq $false)
    {
        $parts = $streamReader.ReadLine().Split("$")
        # The seemingly superfluous '-as' below was for PowerShell 2.0.  Without it, a cast exception was thrown when trying to add the object to a generic collection. 
        $parameters[(ConvertFromBase64String $parts[0])] = ConvertFromBase64String $parts[1] -as [string]
    }
	$streamReader.Dispose() | Out-Null
	$cryptoStream.Dispose() | Out-Null
	$memoryStream.Dispose() | Out-Null

	# RijndaelManaged/RijndaelManagedTransform implemented IDiposable explicitly
	[System.IDisposable].GetMethod("Dispose").Invoke($decryptor, @()) | Out-Null
	[System.IDisposable].GetMethod("Dispose").Invoke($algorithm, @()) | Out-Null
	
	return $parameters
}

function Initialize-ProxySettings() 
{
	$proxyUsername = $env:TentacleProxyUsername
	$proxyPassword = $env:TentacleProxyPassword
	$proxyHost = $env:TentacleProxyHost
	[int]$proxyPort = $env:TentacleProxyPort
	
	$useSystemProxy = [string]::IsNullOrEmpty($proxyHost) 
	
	if($useSystemProxy)
	{
		$proxy = [System.Net.WebRequest]::GetSystemWebProxy()
	}	
	else
	{
		$proxyUri = [System.Uri]"http://${proxyHost}:$proxyPort"
		$proxy = New-Object System.Net.WebProxy($proxyUri)
	}

	if ([string]::IsNullOrEmpty($proxyUsername)) 
	{
		if($useSystemProxy)
		{
			$proxy.Credentials = [System.Net.CredentialCache]::DefaultCredentials
		}
		else
		{
			$proxy.Credentials = New-Object System.Net.NetworkCredential("","")
		}
	}
	else 
	{
		$proxy.Credentials = New-Object System.Net.NetworkCredential($proxyUsername, $proxyPassword)
	}

	[System.Net.WebRequest]::DefaultWebProxy = $proxy
}

function Execute-WithRetry([ScriptBlock] $command, [int] $maxFailures = 3, [int] $sleepBetweenFailures = 1) {
	$attemptCount = 0
	$operationIncomplete = $true

	while ($operationIncomplete -and $attemptCount -lt $maxFailures) {
		$attemptCount = ($attemptCount + 1)

		if ($attemptCount -ge 2) {
			Write-Host "Waiting for $sleepBetweenFailures seconds before retrying..."
			Start-Sleep -s $sleepBetweenFailures
			Write-Host "Retrying..."
		}

		try {
			& $command

			$operationIncomplete = $false
		} catch [System.Exception] {
			if ($attemptCount -lt ($maxFailures)) {
				Write-Host ("Attempt $attemptCount of $maxFailures failed: " + $_.Exception.Message)
			} else {
				throw
			}
		}
	}
}

function Import-CalamariModules() {
	if ($OctopusParameters.ContainsKey("Octopus.Calamari.Bootstrapper.ModulePaths")) {
		$calamariModulePaths = $OctopusParameters["Octopus.Calamari.Bootstrapper.ModulePaths"].Split(";", [StringSplitOptions]'RemoveEmptyEntries')
		foreach ($calamariModulePath in $calamariModulePaths) {
		    if($calamariModulePath.EndsWith(".psd1")) {
		        Import-Module –Name $calamariModulePath.Replace("{{TentacleHome}}", $env:TentacleHome)
		    } else {
        		$env:PSModulePath = $calamariModulePath + ";" + $env:PSModulePath
		    }
		}
	}
}

Log-VersionTable

# -----------------------------------------------------------------
# Variables
# -----------------------------------------------------------------

$MaximumVariableCount=32768
$OctopusParameters = Decrypt-Variables 'qUQe2Yd3XQDG8C/S9HfUqA==' @'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'@

if (-Not (test-path variable:global:OctopusAgentProgramDirectoryPath)) {
  ${OctopusAgentProgramDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BZ2VudC5Qcm9ncmFtRGlyZWN0b3J5UGF0aA=="))]
}
if (-Not (test-path variable:global:OctopusDeploymentId)) {
  ${OctopusDeploymentId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50Lklk"))]
}
if (-Not (test-path variable:global:OctopusDeploymentName)) {
  ${OctopusDeploymentName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50Lk5hbWU="))]
}
if (-Not (test-path variable:global:OctopusDeploymentCreated)) {
  ${OctopusDeploymentCreated} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkNyZWF0ZWQ="))]
}
if (-Not (test-path variable:global:OctopusDeploymentCreatedUtc)) {
  ${OctopusDeploymentCreatedUtc} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkNyZWF0ZWRVdGM="))]
}
if (-Not (test-path variable:global:OctopusDeploymentComments)) {
  ${OctopusDeploymentComments} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkNvbW1lbnRz"))]
}
if (-Not (test-path variable:global:OctopusDeploymentForcePackageDownload)) {
  ${OctopusDeploymentForcePackageDownload} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkZvcmNlUGFja2FnZURvd25sb2Fk"))]
}
if (-Not (test-path variable:global:OctopusDeploymentSpecificMachines)) {
  ${OctopusDeploymentSpecificMachines} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LlNwZWNpZmljTWFjaGluZXM="))]
}
if (-Not (test-path variable:global:OctopusDeploymentExcludedMachines)) {
  ${OctopusDeploymentExcludedMachines} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkV4Y2x1ZGVkTWFjaGluZXM="))]
}
if (-Not (test-path variable:global:OctopusProjectId)) {
  ${OctopusProjectId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5Qcm9qZWN0Lklk"))]
}
if (-Not (test-path variable:global:OctopusProjectName)) {
  ${OctopusProjectName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5Qcm9qZWN0Lk5hbWU="))]
}
if (-Not (test-path variable:global:OctopusProjectGroupId)) {
  ${OctopusProjectGroupId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5Qcm9qZWN0R3JvdXAuSWQ="))]
}
if (-Not (test-path variable:global:OctopusProjectGroupName)) {
  ${OctopusProjectGroupName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5Qcm9qZWN0R3JvdXAuTmFtZQ=="))]
}
if (-Not (test-path variable:global:OctopusEnvironmentId)) {
  ${OctopusEnvironmentId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5FbnZpcm9ubWVudC5JZA=="))]
}
if (-Not (test-path variable:global:OctopusEnvironmentName)) {
  ${OctopusEnvironmentName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5FbnZpcm9ubWVudC5OYW1l"))]
}
if (-Not (test-path variable:global:OctopusEnvironmentSortOrder)) {
  ${OctopusEnvironmentSortOrder} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5FbnZpcm9ubWVudC5Tb3J0T3JkZXI="))]
}
if (-Not (test-path variable:global:OctopusReleaseId)) {
  ${OctopusReleaseId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLklk"))]
}
if (-Not (test-path variable:global:OctopusReleaseNumber)) {
  ${OctopusReleaseNumber} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLk51bWJlcg=="))]
}
if (-Not (test-path variable:global:OctopusReleaseNotes)) {
  ${OctopusReleaseNotes} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLk5vdGVz"))]
}
if (-Not (test-path variable:global:OctopusTaskId)) {
  ${OctopusTaskId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UYXNrLklk"))]
}
if (-Not (test-path variable:global:OctopusTaskName)) {
  ${OctopusTaskName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UYXNrLk5hbWU="))]
}
if (-Not (test-path variable:global:OctopusTaskQueueTime)) {
  ${OctopusTaskQueueTime} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UYXNrLlF1ZXVlVGltZQ=="))]
}
if (-Not (test-path variable:global:OctopusTaskQueueTimeExpiry)) {
  ${OctopusTaskQueueTimeExpiry} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UYXNrLlF1ZXVlVGltZUV4cGlyeQ=="))]
}
if (-Not (test-path variable:global:OctopusReleaseChannelId)) {
  ${OctopusReleaseChannelId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLkNoYW5uZWwuSWQ="))]
}
if (-Not (test-path variable:global:OctopusReleaseChannelName)) {
  ${OctopusReleaseChannelName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLkNoYW5uZWwuTmFtZQ=="))]
}
if (-Not (test-path variable:global:OctopusWebBaseUrl)) {
  ${OctopusWebBaseUrl} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5XZWIuQmFzZVVybA=="))]
}
if (-Not (test-path variable:global:OctopusWebDeploymentLink)) {
  ${OctopusWebDeploymentLink} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5XZWIuRGVwbG95bWVudExpbms="))]
}
if (-Not (test-path variable:global:OctopusWebReleaseLink)) {
  ${OctopusWebReleaseLink} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5XZWIuUmVsZWFzZUxpbms="))]
}
if (-Not (test-path variable:global:OctopusWebProjectLink)) {
  ${OctopusWebProjectLink} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5XZWIuUHJvamVjdExpbms="))]
}
if (-Not (test-path variable:global:OctopusActionNumber)) {
  ${OctopusActionNumber} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uTnVtYmVy"))]
}
if (-Not (test-path variable:global:OctopusActionStepName)) {
  ${OctopusActionStepName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uU3RlcE5hbWU="))]
}
if (-Not (test-path variable:global:OctopusStepNumber)) {
  ${OctopusStepNumber} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5TdGVwLk51bWJlcg=="))]
}
if (-Not (test-path variable:global:OctopusActionPackagePackageVersion)) {
  ${OctopusActionPackagePackageVersion} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5QYWNrYWdlVmVyc2lvbg=="))]
}
if (-Not (test-path variable:global:OctopusStepId)) {
  ${OctopusStepId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5TdGVwLklk"))]
}
if (-Not (test-path variable:global:OctopusStepName)) {
  ${OctopusStepName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5TdGVwLk5hbWU="))]
}
if (-Not (test-path variable:global:OctopusActionTargetRoles)) {
  ${OctopusActionTargetRoles} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uVGFyZ2V0Um9sZXM="))]
}
if (-Not (test-path variable:global:OctopusActionId)) {
  ${OctopusActionId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uSWQ="))]
}
if (-Not (test-path variable:global:OctopusActionName)) {
  ${OctopusActionName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uTmFtZQ=="))]
}
if (-Not (test-path variable:global:OctopusActionPackageAutomaticallyRunConfigurationTransformationFiles)) {
  ${OctopusActionPackageAutomaticallyRunConfigurationTransformationFiles} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5BdXRvbWF0aWNhbGx5UnVuQ29uZmlndXJhdGlvblRyYW5zZm9ybWF0aW9uRmlsZXM="))]
}
if (-Not (test-path variable:global:OctopusActionPackageAutomaticallyUpdateAppSettingsAndConnectionStrings)) {
  ${OctopusActionPackageAutomaticallyUpdateAppSettingsAndConnectionStrings} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5BdXRvbWF0aWNhbGx5VXBkYXRlQXBwU2V0dGluZ3NBbmRDb25uZWN0aW9uU3RyaW5ncw=="))]
}
if (-Not (test-path variable:global:OctopusActionEnabledFeatures)) {
  ${OctopusActionEnabledFeatures} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uRW5hYmxlZEZlYXR1cmVz"))]
}
if (-Not (test-path variable:global:OctopusActionPackageDownloadOnTentacle)) {
  ${OctopusActionPackageDownloadOnTentacle} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5Eb3dubG9hZE9uVGVudGFjbGU="))]
}
if (-Not (test-path variable:global:OctopusActionPackageFeedId)) {
  ${OctopusActionPackageFeedId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5GZWVkSWQ="))]
}
if (-Not (test-path variable:global:OctopusActionPackagePackageId)) {
  ${OctopusActionPackagePackageId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5QYWNrYWdlSWQ="))]
}
if (-Not (test-path variable:global:OctopusActionPackageCustomInstallationDirectory)) {
  ${OctopusActionPackageCustomInstallationDirectory} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5DdXN0b21JbnN0YWxsYXRpb25EaXJlY3Rvcnk="))]
}
if (-Not (test-path variable:global:OctopusActionPackageCustomInstallationDirectoryShouldBePurgedBeforeDeployment)) {
  ${OctopusActionPackageCustomInstallationDirectoryShouldBePurgedBeforeDeployment} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5DdXN0b21JbnN0YWxsYXRpb25EaXJlY3RvcnlTaG91bGRCZVB1cmdlZEJlZm9yZURlcGxveW1lbnQ="))]
}
if (-Not (test-path variable:global:OctopusActionCustomScriptsDeployps1)) {
  ${OctopusActionCustomScriptsDeployps1} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uQ3VzdG9tU2NyaXB0cy5EZXBsb3kucHMx"))]
}
if (-Not (test-path variable:global:OctopusDeploymentCreatedById)) {
  ${OctopusDeploymentCreatedById} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkNyZWF0ZWRCeS5JZA=="))]
}
if (-Not (test-path variable:global:OctopusDeploymentCreatedByUsername)) {
  ${OctopusDeploymentCreatedByUsername} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkNyZWF0ZWRCeS5Vc2VybmFtZQ=="))]
}
if (-Not (test-path variable:global:OctopusDeploymentCreatedByDisplayName)) {
  ${OctopusDeploymentCreatedByDisplayName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkNyZWF0ZWRCeS5EaXNwbGF5TmFtZQ=="))]
}
if (-Not (test-path variable:global:OctopusDeploymentCreatedByEmailAddress)) {
  ${OctopusDeploymentCreatedByEmailAddress} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkNyZWF0ZWRCeS5FbWFpbEFkZHJlc3M="))]
}
if (-Not (test-path variable:global:OctopusTentacleCurrentDeploymentRetentionPolicySubset)) {
  ${OctopusTentacleCurrentDeploymentRetentionPolicySubset} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5DdXJyZW50RGVwbG95bWVudC5SZXRlbnRpb25Qb2xpY3lTdWJzZXQ="))]
}
if (-Not (test-path variable:global:OctopusRetentionPolicySet)) {
  ${OctopusRetentionPolicySet} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1c1JldGVudGlvblBvbGljeVNldA=="))]
}
if (-Not (test-path variable:global:OctopusRetentionPolicyItemsToKeep)) {
  ${OctopusRetentionPolicyItemsToKeep} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1c1JldGVudGlvblBvbGljeUl0ZW1zVG9LZWVw"))]
}
if (-Not (test-path variable:global:OctopusUseGuidedFailure)) {
  ${OctopusUseGuidedFailure} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1c1VzZUd1aWRlZEZhaWx1cmU="))]
}
if (-Not (test-path variable:global:InstallDir)) {
  ${InstallDir} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("SW5zdGFsbERpcg=="))]
}
if (-Not (test-path variable:global:OctopusReleasePreviousId)) {
  ${OctopusReleasePreviousId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLlByZXZpb3VzLklk"))]
}
if (-Not (test-path variable:global:OctopusReleasePreviousNumber)) {
  ${OctopusReleasePreviousNumber} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLlByZXZpb3VzLk51bWJlcg=="))]
}
if (-Not (test-path variable:global:OctopusReleasePreviousForEnvironmentId)) {
  ${OctopusReleasePreviousForEnvironmentId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLlByZXZpb3VzRm9yRW52aXJvbm1lbnQuSWQ="))]
}
if (-Not (test-path variable:global:OctopusReleasePreviousForEnvironmentNumber)) {
  ${OctopusReleasePreviousForEnvironmentNumber} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLlByZXZpb3VzRm9yRW52aXJvbm1lbnQuTnVtYmVy"))]
}
if (-Not (test-path variable:global:OctopusReleaseCurrentForEnvironmentId)) {
  ${OctopusReleaseCurrentForEnvironmentId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLkN1cnJlbnRGb3JFbnZpcm9ubWVudC5JZA=="))]
}
if (-Not (test-path variable:global:OctopusReleaseCurrentForEnvironmentNumber)) {
  ${OctopusReleaseCurrentForEnvironmentNumber} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLkN1cnJlbnRGb3JFbnZpcm9ubWVudC5OdW1iZXI="))]
}
if (-Not (test-path variable:global:OctopusDeploymentPreviousSuccessfulId)) {
  ${OctopusDeploymentPreviousSuccessfulId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LlByZXZpb3VzU3VjY2Vzc2Z1bC5JZA=="))]
}
if (-Not (test-path variable:global:OctopusActionPackageNuGetPackageId)) {
  ${OctopusActionPackageNuGetPackageId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5OdUdldFBhY2thZ2VJZA=="))]
}
if (-Not (test-path variable:global:OctopusActionPackageNuGetPackageVersion)) {
  ${OctopusActionPackageNuGetPackageVersion} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5OdUdldFBhY2thZ2VWZXJzaW9u"))]
}
if (-Not (test-path variable:global:OctopusActionPackageNuGetFeedId)) {
  ${OctopusActionPackageNuGetFeedId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5OdUdldEZlZWRJZA=="))]
}
if (-Not (test-path variable:global:OctopusDeploymentMachines)) {
  ${OctopusDeploymentMachines} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50Lk1hY2hpbmVz"))]
}
if (-Not (test-path variable:global:OctopusMachineId)) {
  ${OctopusMachineId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5NYWNoaW5lLklk"))]
}
if (-Not (test-path variable:global:OctopusMachineName)) {
  ${OctopusMachineName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5NYWNoaW5lLk5hbWU="))]
}
if (-Not (test-path variable:global:OctopusTentacleAgentApplicationDirectoryPath)) {
  ${OctopusTentacleAgentApplicationDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5BZ2VudC5BcHBsaWNhdGlvbkRpcmVjdG9yeVBhdGg="))]
}
if (-Not (test-path variable:global:OctopusTentacleAgentInstanceName)) {
  ${OctopusTentacleAgentInstanceName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5BZ2VudC5JbnN0YW5jZU5hbWU="))]
}
if (-Not (test-path variable:global:OctopusTentacleAgentProgramDirectoryPath)) {
  ${OctopusTentacleAgentProgramDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5BZ2VudC5Qcm9ncmFtRGlyZWN0b3J5UGF0aA=="))]
}
if (-Not (test-path variable:global:OctopusMachineCommunicationStyle)) {
  ${OctopusMachineCommunicationStyle} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5NYWNoaW5lLkNvbW11bmljYXRpb25TdHlsZQ=="))]
}
if (-Not (test-path variable:global:OctopusMachineHostname)) {
  ${OctopusMachineHostname} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5NYWNoaW5lLkhvc3RuYW1l"))]
}
if (-Not (test-path variable:global:OctopusMachineRoles)) {
  ${OctopusMachineRoles} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5NYWNoaW5lLlJvbGVz"))]
}
if (-Not (test-path variable:global:OctopusMachineTags)) {
  ${OctopusMachineTags} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5NYWNoaW5lLlRhZ3M="))]
}
if (-Not (test-path variable:global:OctopusMachineTenantIds)) {
  ${OctopusMachineTenantIds} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5NYWNoaW5lLlRlbmFudElkcw=="))]
}
if (-Not (test-path variable:global:OctopusTentacleCurrentDeploymentPackageFilePath)) {
  ${OctopusTentacleCurrentDeploymentPackageFilePath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5DdXJyZW50RGVwbG95bWVudC5QYWNrYWdlRmlsZVBhdGg="))]
}
if (-Not (test-path variable:global:OctopusTentacleCurrentDeploymentTargetedRoles)) {
  ${OctopusTentacleCurrentDeploymentTargetedRoles} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5DdXJyZW50RGVwbG95bWVudC5UYXJnZXRlZFJvbGVz"))]
}
if (-Not (test-path variable:global:envSystemDrive)) {
  ${envSystemDrive} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlN5c3RlbURyaXZl"))]
}
if (-Not (test-path variable:global:envProgramFilesx86)) {
  ${envProgramFilesx86} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlByb2dyYW1GaWxlcyh4ODYp"))]
}
if (-Not (test-path variable:global:envPath)) {
  ${envPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBhdGg="))]
}
if (-Not (test-path variable:global:envProgramW6432)) {
  ${envProgramW6432} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlByb2dyYW1XNjQzMg=="))]
}
if (-Not (test-path variable:global:envwindir)) {
  ${envwindir} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OndpbmRpcg=="))]
}
if (-Not (test-path variable:global:envPROCESSORIDENTIFIER)) {
  ${envPROCESSORIDENTIFIER} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9JREVOVElGSUVS"))]
}
if (-Not (test-path variable:global:envPROCESSOR_IDENTIFIER)) {
  ${envPROCESSOR_IDENTIFIER} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9JREVOVElGSUVS"))]
}
if (-Not (test-path variable:global:envTMP)) {
  ${envTMP} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRNUA=="))]
}
if (-Not (test-path variable:global:envPROCESSORARCHITECTURE)) {
  ${envPROCESSORARCHITECTURE} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9BUkNISVRFQ1RVUkU="))]
}
if (-Not (test-path variable:global:envPROCESSOR_ARCHITECTURE)) {
  ${envPROCESSOR_ARCHITECTURE} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9BUkNISVRFQ1RVUkU="))]
}
if (-Not (test-path variable:global:envPATHEXT)) {
  ${envPATHEXT} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBBVEhFWFQ="))]
}
if (-Not (test-path variable:global:envAgentProgramDirectoryPath)) {
  ${envAgentProgramDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkFnZW50UHJvZ3JhbURpcmVjdG9yeVBhdGg="))]
}
if (-Not (test-path variable:global:envPROCESSORREVISION)) {
  ${envPROCESSORREVISION} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9SRVZJU0lPTg=="))]
}
if (-Not (test-path variable:global:envPROCESSOR_REVISION)) {
  ${envPROCESSOR_REVISION} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9SRVZJU0lPTg=="))]
}
if (-Not (test-path variable:global:envTEMP)) {
  ${envTEMP} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRFTVA="))]
}
if (-Not (test-path variable:global:envUSERPROFILE)) {
  ${envUSERPROFILE} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlVTRVJQUk9GSUxF"))]
}
if (-Not (test-path variable:global:envTentacleVersion)) {
  ${envTentacleVersion} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlVmVyc2lvbg=="))]
}
if (-Not (test-path variable:global:envTentacleJournal)) {
  ${envTentacleJournal} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlSm91cm5hbA=="))]
}
if (-Not (test-path variable:global:envTentacleApplications)) {
  ${envTentacleApplications} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlQXBwbGljYXRpb25z"))]
}
if (-Not (test-path variable:global:envTentacleProgramDirectoryPath)) {
  ${envTentacleProgramDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlUHJvZ3JhbURpcmVjdG9yeVBhdGg="))]
}
if (-Not (test-path variable:global:envTentacleInstanceName)) {
  ${envTentacleInstanceName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlSW5zdGFuY2VOYW1l"))]
}
if (-Not (test-path variable:global:envUSERDNSDOMAIN)) {
  ${envUSERDNSDOMAIN} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlVTRVJETlNET01BSU4="))]
}
if (-Not (test-path variable:global:envFPNOHOSTCHECK)) {
  ${envFPNOHOSTCHECK} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkZQX05PX0hPU1RfQ0hFQ0s="))]
}
if (-Not (test-path variable:global:envFP_NO_HOST_CHECK)) {
  ${envFP_NO_HOST_CHECK} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkZQX05PX0hPU1RfQ0hFQ0s="))]
}
if (-Not (test-path variable:global:envCommonProgramFiles)) {
  ${envCommonProgramFiles} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkNvbW1vblByb2dyYW1GaWxlcw=="))]
}
if (-Not (test-path variable:global:envTentacleCertificateSignatureAlgorithm)) {
  ${envTentacleCertificateSignatureAlgorithm} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlQ2VydGlmaWNhdGVTaWduYXR1cmVBbGdvcml0aG0="))]
}
if (-Not (test-path variable:global:envProgramData)) {
  ${envProgramData} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlByb2dyYW1EYXRh"))]
}
if (-Not (test-path variable:global:envHOMEPATH)) {
  ${envHOMEPATH} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkhPTUVQQVRI"))]
}
if (-Not (test-path variable:global:envCOMPUTERNAME)) {
  ${envCOMPUTERNAME} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkNPTVBVVEVSTkFNRQ=="))]
}
if (-Not (test-path variable:global:envTentacleProxyPort)) {
  ${envTentacleProxyPort} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlUHJveHlQb3J0"))]
}
if (-Not (test-path variable:global:envALLUSERSPROFILE)) {
  ${envALLUSERSPROFILE} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkFMTFVTRVJTUFJPRklMRQ=="))]
}
if (-Not (test-path variable:global:envCommonProgramW6432)) {
  ${envCommonProgramW6432} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkNvbW1vblByb2dyYW1XNjQzMg=="))]
}
if (-Not (test-path variable:global:envTentacleHome)) {
  ${envTentacleHome} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlSG9tZQ=="))]
}
if (-Not (test-path variable:global:envASPNETENV)) {
  ${envASPNETENV} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkFTUE5FVF9FTlY="))]
}
if (-Not (test-path variable:global:envASPNET_ENV)) {
  ${envASPNET_ENV} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkFTUE5FVF9FTlY="))]
}
if (-Not (test-path variable:global:envCommonProgramFilesx86)) {
  ${envCommonProgramFilesx86} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkNvbW1vblByb2dyYW1GaWxlcyh4ODYp"))]
}
if (-Not (test-path variable:global:envHOMEDRIVE)) {
  ${envHOMEDRIVE} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkhPTUVEUklWRQ=="))]
}
if (-Not (test-path variable:global:envSystemRoot)) {
  ${envSystemRoot} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlN5c3RlbVJvb3Q="))]
}
if (-Not (test-path variable:global:envNUMBEROFPROCESSORS)) {
  ${envNUMBEROFPROCESSORS} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52Ok5VTUJFUl9PRl9QUk9DRVNTT1JT"))]
}
if (-Not (test-path variable:global:envNUMBER_OF_PROCESSORS)) {
  ${envNUMBER_OF_PROCESSORS} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52Ok5VTUJFUl9PRl9QUk9DRVNTT1JT"))]
}
if (-Not (test-path variable:global:envOS)) {
  ${envOS} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52Ok9T"))]
}
if (-Not (test-path variable:global:envTentacleExecutablePath)) {
  ${envTentacleExecutablePath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlRXhlY3V0YWJsZVBhdGg="))]
}
if (-Not (test-path variable:global:envProgramFiles)) {
  ${envProgramFiles} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlByb2dyYW1GaWxlcw=="))]
}
if (-Not (test-path variable:global:envComSpec)) {
  ${envComSpec} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkNvbVNwZWM="))]
}
if (-Not (test-path variable:global:envUSERNAME)) {
  ${envUSERNAME} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlVTRVJOQU1F"))]
}
if (-Not (test-path variable:global:envLOGONSERVER)) {
  ${envLOGONSERVER} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkxPR09OU0VSVkVS"))]
}
if (-Not (test-path variable:global:envPSModulePath)) {
  ${envPSModulePath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBTTW9kdWxlUGF0aA=="))]
}
if (-Not (test-path variable:global:envAPPDATA)) {
  ${envAPPDATA} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkFQUERBVEE="))]
}
if (-Not (test-path variable:global:envUSERDOMAIN)) {
  ${envUSERDOMAIN} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlVTRVJET01BSU4="))]
}
if (-Not (test-path variable:global:envPROCESSORLEVEL)) {
  ${envPROCESSORLEVEL} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9MRVZFTA=="))]
}
if (-Not (test-path variable:global:envPROCESSOR_LEVEL)) {
  ${envPROCESSOR_LEVEL} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9MRVZFTA=="))]
}
if (-Not (test-path variable:global:envLOCALAPPDATA)) {
  ${envLOCALAPPDATA} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkxPQ0FMQVBQREFUQQ=="))]
}
if (-Not (test-path variable:global:envPSExecutionPolicyPreference)) {
  ${envPSExecutionPolicyPreference} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBTRXhlY3V0aW9uUG9saWN5UHJlZmVyZW5jZQ=="))]
}
if (-Not (test-path variable:global:envUSERDOMAINROAMINGPROFILE)) {
  ${envUSERDOMAINROAMINGPROFILE} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlVTRVJET01BSU5fUk9BTUlOR1BST0ZJTEU="))]
}
if (-Not (test-path variable:global:envUSERDOMAIN_ROAMINGPROFILE)) {
  ${envUSERDOMAIN_ROAMINGPROFILE} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlVTRVJET01BSU5fUk9BTUlOR1BST0ZJTEU="))]
}
if (-Not (test-path variable:global:envPUBLIC)) {
  ${envPUBLIC} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBVQkxJQw=="))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousInstallationOriginalInstalledPath)) {
  ${OctopusTentaclePreviousInstallationOriginalInstalledPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c0luc3RhbGxhdGlvbi5PcmlnaW5hbEluc3RhbGxlZFBhdGg="))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousInstallationCustomInstallationDirectory)) {
  ${OctopusTentaclePreviousInstallationCustomInstallationDirectory} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c0luc3RhbGxhdGlvbi5DdXN0b21JbnN0YWxsYXRpb25EaXJlY3Rvcnk="))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousInstallationPackageFilePath)) {
  ${OctopusTentaclePreviousInstallationPackageFilePath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c0luc3RhbGxhdGlvbi5QYWNrYWdlRmlsZVBhdGg="))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousInstallationPackageVersion)) {
  ${OctopusTentaclePreviousInstallationPackageVersion} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c0luc3RhbGxhdGlvbi5QYWNrYWdlVmVyc2lvbg=="))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousSuccessfulInstallationOriginalInstalledPath)) {
  ${OctopusTentaclePreviousSuccessfulInstallationOriginalInstalledPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c1N1Y2Nlc3NmdWxJbnN0YWxsYXRpb24uT3JpZ2luYWxJbnN0YWxsZWRQYXRo"))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousSuccessfulInstallationCustomInstallationDirectory)) {
  ${OctopusTentaclePreviousSuccessfulInstallationCustomInstallationDirectory} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c1N1Y2Nlc3NmdWxJbnN0YWxsYXRpb24uQ3VzdG9tSW5zdGFsbGF0aW9uRGlyZWN0b3J5"))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousSuccessfulInstallationPackageFilePath)) {
  ${OctopusTentaclePreviousSuccessfulInstallationPackageFilePath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c1N1Y2Nlc3NmdWxJbnN0YWxsYXRpb24uUGFja2FnZUZpbGVQYXRo"))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousSuccessfulInstallationPackageVersion)) {
  ${OctopusTentaclePreviousSuccessfulInstallationPackageVersion} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c1N1Y2Nlc3NmdWxJbnN0YWxsYXRpb24uUGFja2FnZVZlcnNpb24="))]
}
if (-Not (test-path variable:global:OctopusOriginalPackageDirectoryPath)) {
  ${OctopusOriginalPackageDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1c09yaWdpbmFsUGFja2FnZURpcmVjdG9yeVBhdGg="))]
}
if (-Not (test-path variable:global:OctopusActionPackageInstallationDirectoryPath)) {
  ${OctopusActionPackageInstallationDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5JbnN0YWxsYXRpb25EaXJlY3RvcnlQYXRo"))]
}
if (-Not (test-path variable:global:PackageInstallationDirectoryPath)) {
  ${PackageInstallationDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("UGFja2FnZS5JbnN0YWxsYXRpb25EaXJlY3RvcnlQYXRo"))]
}
if (-Not (test-path variable:global:PackageExtractedFileCount)) {
  ${PackageExtractedFileCount} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("UGFja2FnZS5FeHRyYWN0ZWRGaWxlQ291bnQ="))]
}
if (-Not (test-path variable:global:OctopusAppliedXmlConfigTransforms)) {
  ${OctopusAppliedXmlConfigTransforms} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1c0FwcGxpZWRYbWxDb25maWdUcmFuc2Zvcm1z"))]
}
if (-Not (test-path variable:global:PackageCopiedFileCount)) {
  ${PackageCopiedFileCount} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("UGFja2FnZS5Db3BpZWRGaWxlQ291bnQ="))]
}


# -----------------------------------------------------------------
# Script Modules - after variables
# -----------------------------------------------------------------



# -----------------------------------------------------------------
# Defaults
# -----------------------------------------------------------------

Initialize-ProxySettings

Log-EnvironmentInformation

# -----------------------------------------------------------------
# Invoke target script
# -----------------------------------------------------------------
Import-CalamariModules

# -----------------------------------------------------------------
# Invoke target script
# -----------------------------------------------------------------

. 'C:\inetpub\wwwroot\dev-assist.acr.org\simulator-npmdeploy\Octopus.Action.CustomScripts.Deploy.ps1' 

# -----------------------------------------------------------------
# Ensure we exit with whatever exit code the last exe used
# -----------------------------------------------------------------

if ((test-path variable:global:lastexitcode)) 
{
	exit $LastExitCode 
}
